DatasetGenerator class abstract interface

Produces canonical DatasetEntry values from a source document.

Implementations must not depend on a particular LLM provider. LLM-backed generation can be supplied by user adapters outside this package.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(DatasetSourceDocument document) Stream<DatasetEntry>
Generates zero or more canonical entries for document.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited