LengthValidator class
Configurable min/max character lengths for input/output.
- Implemented types
Constructors
- LengthValidator({int minInputLength = 1, int? maxInputLength, int? minOutputLength, int? maxOutputLength})
-
Creates a length validator.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxInputLength → int?
-
Maximum input length (inclusive), or null for unlimited.
final
- maxOutputLength → int?
-
Maximum output length when output is non-null.
final
- minInputLength → int
-
Minimum input length (inclusive).
final
- minOutputLength → int?
-
Minimum output length when output is non-null.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
DatasetEntry entry) → Future< DatasetValidationResult> -
Validates
entryand returns a structured result.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited