ParagraphGenerator class
Builds canonical paragraph entries from ParagraphPatternConfig.
- Implemented types
Constructors
-
ParagraphGenerator({required GeneratorConfig config, required Map<
String, ParagraphPatternConfig> patterns, required TextLexicon lexicon, String generatorVersion = '1.0.0'}) - Creates a paragraph generator.
Properties
- config → GeneratorConfig
-
Shared generator configuration.
final
- generatorVersion → String
-
Provenance version string.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lexicon → TextLexicon
-
Lexicon for canonical slot resolution.
final
-
patterns
→ Map<
String, ParagraphPatternConfig> -
Paragraph patterns keyed by ParagraphPatternConfig.id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
DatasetSourceDocument document) → Stream< DatasetEntry> -
Generates zero or more canonical entries for
document.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited